import { BigNumberish, BytesLike, ethers } from "ethers";
import { AccessListish } from "ethers/lib/utils";
export declare enum LitChainIds {
    ethereum = 1,
    polygon = 137,
    fantom = 250,
    bsc = 56,
    arbitrum = 42161,
    avalanche = 43114,
    fuji = 43113,
    harmony = 1666600000,
    mumbai = 80001,
    goerli = 5,
    cronos = 25,
    optimism = 10,
    celo = 42220,
    aurora = 1313161554,
    alfajores = 44787,
    xdc = 50,
    evmos = 9001,
    evmosTestnet = 9000,
    hardhat = 31337
}
export declare enum CHAIN_NAME {
    ETHEREUM = "ethereum",
    POLYGON = "polygon",
    FANTOM = "fantom",
    BSC = "bsc",
    ARBITRUM = "arbitrum",
    AVALANCHE = "avalanche",
    FUJI = "fuji",
    HARMONY = "harmony",
    MUMBAI = "mumbai",
    GOERLI = "goerli",
    CRONOS = "cronos",
    OPTIMISM = "optimism",
    CELO = "celo",
    AURORA = "aurora",
    ALFAJORES = "alfajores",
    XDC = "xdc",
    EVMOS = "evmos",
    EVMOSTESTNET = "evmosTestnet",
    HARDHAT = "hardhat"
}
export declare enum RunStatus {
    EXIT_RUN = 0,
    ACTION_RUN = 1,
    CONTINUE_RUN = 2
}
export interface LitActionsSDK {
    signEcdsa: ({ toSign, publicKey, sigName, }: {
        toSign: Uint8Array;
        publicKey: `0x04${string}` | string;
        sigName: string;
    }) => Promise<void>;
    getLatestNonce: (chain: string) => Promise<number>;
    setResponse: ({ response }: {
        response: string;
    }) => void;
}
export type UnsignedTransactionData = {
    contractAddress?: `0x${string}`;
    nonce?: number;
    gasLimit?: BigNumberish;
    value?: BigNumberish;
    chainId?: CHAIN_NAME;
    maxPriorityFeePerGas?: BigNumberish;
    maxFeePerGas?: BigNumberish;
    from: `0x${string}`;
    functionName: string;
    args: any[];
    abi: ethers.ContractInterface;
};
export type UnsignedTransaction = {
    to?: `0x${string}`;
    nonce?: number;
    gasLimit?: BigNumberish;
    data?: BytesLike;
    value?: BigNumberish;
    chainId?: number;
    type?: number | null;
    accessList?: AccessListish;
    maxPriorityFeePerGas?: BigNumberish;
    maxFeePerGas?: BigNumberish;
};
export type LitUnsignedTransaction = UnsignedTransaction & {
    from: `0x${string}` | "{{publicKey}}";
};
export interface CustomAction {
    type: "custom";
    priority: number;
    code: string;
    args?: Object;
}
export interface ContractAction {
    type: "contract";
    priority: number;
    contractAddress: `0x${string}`;
    abi: ethers.ContractInterface;
    functionName: string;
    chainId: CHAIN_NAME;
    providerURL: string;
    nonce?: number;
    gasLimit?: BigNumberish;
    value?: BigNumberish;
    from?: `0x${string}`;
    maxPriorityFeePerGas?: BigNumberish;
    maxFeePerGas?: BigNumberish;
    args?: any[];
}
export interface FetchAction {
    type: "fetch";
    priority: number;
    baseUrl: string;
    endpoint: string;
    responsePath: string;
    apiKey?: string;
    toSign?: Uint8Array;
    signCondition?: {
        type: "&&" | "||";
        operator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=";
        value: number | string | bigint | string[] | number[] | bigint[] | undefined | (string | number | bigint)[];
    }[];
}
export type Action = CustomAction | ContractAction | FetchAction;
export interface IThresholdConditionalLogic {
    type: "THRESHOLD";
    value: number;
    interval?: number;
}
export interface ITargetConditionalLogic {
    type: "TARGET";
    targetCondition: string;
    interval?: number;
}
export interface IEveryConditionalLogic {
    type: "EVERY";
    interval?: number;
}
export type IConditionalLogic = IThresholdConditionalLogic | ITargetConditionalLogic | IEveryConditionalLogic;
export interface IContractCondition {
    contractAddress: `0x${string}`;
    abi: ethers.ContractInterface;
    chainId: CHAIN_NAME;
    providerURL: string;
    eventName: string;
    eventArgName: string[];
    expectedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[];
    matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=";
    onMatched: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onUnMatched: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onError: (error: Error) => void;
}
export declare class ContractCondition implements IContractCondition {
    contractAddress: `0x${string}`;
    abi: ethers.ContractInterface;
    chainId: CHAIN_NAME;
    providerURL: string;
    eventName: string;
    eventArgName: string[];
    expectedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[];
    matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=";
    onMatched: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onUnMatched: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onError: (error: Error) => void;
    id?: string;
    sdkOnMatched?: () => Promise<void>;
    sdkOnUnMatched?: () => Promise<void>;
    constructor(contractAddress: `0x${string}`, abi: ethers.ContractInterface, chainId: CHAIN_NAME, providerURL: string, eventName: string, eventArgName: string[], expectedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[], matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=", onMatched?: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>, onUnMatched?: (emittedValue: number[] | string[] | bigint[] | object[] | (string | number | bigint | object)[]) => Promise<void>, onError?: (error: Error) => void);
}
export interface IWebhookCondition {
    baseUrl: string;
    endpoint: string;
    responsePath: string;
    expectedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[];
    matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=";
    apiKey?: string;
    onMatched: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onUnMatched: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onError: (error: Error) => void;
}
export declare class WebhookCondition implements IWebhookCondition {
    baseUrl: string;
    endpoint: string;
    responsePath: string;
    expectedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[];
    matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=";
    apiKey?: string;
    onMatched: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onUnMatched: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>;
    onError: (error: Error) => void;
    id?: string;
    sdkOnMatched?: () => Promise<void>;
    sdkOnUnMatched?: () => Promise<void>;
    constructor(baseUrl: string, endpoint: string, responsePath: string, expectedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[], matchOperator: "<" | ">" | "==" | "===" | "!==" | "!=" | ">=" | "<=", apiKey?: string, onMatched?: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>, onUnMatched?: (emittedValue: number | string | number[] | string[] | bigint | bigint[] | object | object[] | (string | number | bigint | object)[]) => Promise<void>, onError?: (error: Error) => void);
}
export type Condition = ContractCondition | WebhookCondition;
export interface IExecutionConstraints {
    conditionMonitorExecutions?: number;
    startDate?: Date;
    endDate?: Date;
    maxLitActionCompletions?: number;
}
export declare enum LogCategory {
    ERROR = 0,
    RESPONSE = 1,
    CONDITION = 2,
    BROADCAST = 3,
    EXECUTION = 4
}
export interface ILogEntry {
    category: LogCategory;
    message: string;
    responseObject: string;
    isoDate: string;
}
