/// <reference types="node" />
import { EventEmitter } from "events";
import { ethers } from "ethers";
import { SessionSigsMap } from "@lit-protocol/types";
import { Action, Condition, IConditionalLogic, IExecutionConstraints, ILogEntry, LitUnsignedTransaction, LogCategory, UnsignedTransactionData } from "./@types/lit-listener-sdk";
import { LitResourceAbilityRequest } from "@lit-protocol/auth-helpers";
export declare class Circuit extends EventEmitter {
    private isRunning;
    private useSecureKey;
    private conditions;
    private pendingBroadcasts;
    private monitor;
    private conditionalLogic?;
    private satisfiedConditions;
    private actions;
    private conditionExecutedCount;
    private litActionCompletionCount;
    private conditionMonitorExecutions?;
    private startDate?;
    private endDate?;
    private maxLitActionCompletions?;
    private logSize;
    private logs;
    private logIndex;
    private signer;
    private litClient;
    private pkpContract;
    private pkpHelperContract;
    private code;
    private secureKey;
    private ipfsCID;
    private publicKey;
    private pkpAddress;
    private authSig;
    private hasSetActionHelperFunction;
    private continueRun;
    private actionFunctions;
    private emitter;
    private jsParameters;
    private errorHandlingModeStrict;
    private lastSuccessfulNonce;
    private sessionSig;
    constructor(signer?: ethers.Signer, pkpContractAddress?: string, pkpHelperContractAddress?: string, errorHandlingModeStrict?: boolean);
    setConditions: (conditions: Condition[]) => void;
    setConditionalLogic: (logic: IConditionalLogic) => void;
    executionConstraints: (options: IExecutionConstraints) => void;
    setActions: (actions: Action[], useSecureKey?: boolean) => Promise<{
        unsignedTransactionDataObject: {
            [key: string]: LitUnsignedTransaction;
        };
        litActionCode: string;
        secureKey: string;
    }>;
    generateUnsignedTransactionData: (data: UnsignedTransactionData, providerURL: string) => Promise<LitUnsignedTransaction>;
    getIPFSHash: (code: string) => Promise<string>;
    mintGrantBurnPKP: (cidIPFS: string) => Promise<{
        tokenId: string;
        publicKey: `0x04${string}` | string;
        address: string;
    }>;
    start: ({ publicKey, ipfsCID, sessionSig, secureKey, broadcast, }: {
        publicKey: `0x04${string}` | string;
        ipfsCID?: string;
        sessionSig?: SessionSigsMap;
        secureKey?: string;
        broadcast?: boolean;
    }) => Promise<void>;
    getLogs: (category?: LogCategory) => ILogEntry[];
    generateSessionSignature: (pkpPublicKey: string, resources?: LitResourceAbilityRequest[], chainId?: number, uri?: string, version?: string) => Promise<SessionSigsMap>;
    interrupt: () => void;
    private mintNextPKP;
    private getPubKeyByPKPTokenId;
    private runLitAction;
    private connectLit;
    private checkExecutionLimitations;
    private broadcastContractActions;
    private checkConditionalLogicAndRun;
    private log;
}
