"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Circuit = void 0;
const LitJsSdk = __importStar(require("@lit-protocol/lit-node-client"));
const transactions_1 = require("@ethersproject/transactions");
const events_1 = require("events");
const ethers_1 = require("ethers");
const ipfs_only_hash_1 = __importDefault(require("ipfs-only-hash"));
const litProtocol_1 = require("./utils/litProtocol");
const bytes_1 = require("@ethersproject/bytes");
const constants_1 = require("./constants");
const PKPNFT_json_1 = __importDefault(require("./abis/PKPNFT.json"));
const PKPHelper_json_1 = __importDefault(require("./abis/PKPHelper.json"));
const PKPPermissions_json_1 = __importDefault(require("./abis/PKPPermissions.json"));
const lit_listener_sdk_1 = require("./@types/lit-listener-sdk");
const conditions_1 = require("./conditions");
class Circuit extends events_1.EventEmitter {
    constructor(signer, pkpContractAddress = constants_1.PKP_CONTRACT_ADDRESS, pkpHelperContractAddress = constants_1.PKP_HELPER_CONTRACT_ADDRESS, errorHandlingModeStrict = false) {
        super();
        this.isRunning = false;
        this.useSecureKey = false;
        this.conditions = [];
        this.pendingBroadcasts = [];
        this.satisfiedConditions = new Set();
        this.actions = [];
        this.conditionExecutedCount = 0;
        this.litActionCompletionCount = 0;
        this.logSize = 1000;
        this.logs = new Array(this.logSize);
        this.logIndex = 0;
        this.code = "";
        this.hasSetActionHelperFunction = false;
        this.continueRun = true;
        this.emitter = new events_1.EventEmitter();
        this.jsParameters = {};
        this.errorHandlingModeStrict = false;
        this.lastSuccessfulNonce = new Map();
        this.setConditions = (conditions) => {
            conditions.forEach((condition) => {
                condition.id = (this.conditions.length + 1).toString();
                this.conditions.push(condition);
            });
        };
        this.setConditionalLogic = (logic) => {
            this.conditionalLogic = logic;
        };
        this.executionConstraints = (options) => {
            this.conditionMonitorExecutions = options.conditionMonitorExecutions;
            this.startDate = options.startDate;
            this.endDate = options.endDate;
            this.maxLitActionCompletions = options.maxLitActionCompletions;
        };
        this.setActions = async (actions, useSecureKey = false) => {
            this.useSecureKey = useSecureKey;
            if (this.useSecureKey) {
                this.secureKey = (0, litProtocol_1.generateSecureRandomKey)();
            }
            this.actions = this.actions.concat(actions);
            let unsignedTransactionDataObject = {};
            if (!this.hasSetActionHelperFunction) {
                this.code += `const CONDITIONAL_HASH = "${(0, litProtocol_1.hashHex)(this.secureKey)}";
  
      const hashHex = async (input) => {
        const hash = await crypto.subtle.digest("SHA-256", new TextEncoder().encode(input));
        return new Uint8Array(hash);
      }; 

      const concatenatedResponse = {};

      const hashTransaction = (tx) => {
        return ethers.utils.arrayify(
          ethers.utils.keccak256(
            ethers.utils.arrayify(ethers.utils.serializeTransaction(tx)),
          ),
        );
      };

      const checkSignCondition = (responseValue, signCondition) => {
        if (!signCondition) return true;
  
        return signCondition.reduce((previousResult, currentCondition) => {
          const { type, operator, value: conditionValue } = currentCondition;
          let result;
  
          switch (operator) {
            case "<":
              result = responseValue < conditionValue;
              break;
            case ">":
              result = responseValue > conditionValue;
              break;
            case "==":
              result = responseValue == conditionValue;
              break;
            case "===":
              result = responseValue === conditionValue;
              break;
            case "!==":
              result = responseValue !== conditionValue;
              break;
            case "!=":
              result = responseValue != conditionValue;
              break;
            case ">=":
              result = responseValue >= conditionValue;
              break;
            case "<=":
              result = responseValue <= conditionValue;
              break;
            default:
              console.log('Error in checking sign condition: Invalid operator.');
          }
  
          return type === '&&' ? (previousResult && result) : (previousResult || result);
        }, signCondition[0].type === '&&');
      }\n\n
        `;
                this.hasSetActionHelperFunction = true;
            }
            const uniquePriorities = new Set();
            this.actions.forEach((action) => {
                if (uniquePriorities.has(action.priority)) {
                    throw new Error(`Action with priority ${action.priority} already exists.`);
                }
                uniquePriorities.add(action.priority);
            });
            this.actions.sort((a, b) => a.priority - b.priority);
            for (const action of this.actions) {
                let generatedUnsignedData;
                if (action.type === "custom") {
                    Object.assign(this.jsParameters, action.args);
                }
                else if (action.type === "fetch") {
                    Object.assign(this.jsParameters, {
                        [`signConditionFetch${action.priority}`]: action.signCondition,
                        [`toSignFetch${action.priority}`]: action?.toSign
                            ? action?.toSign
                            : action.signCondition[action.priority].value,
                    });
                }
                else {
                    generatedUnsignedData = await this.generateUnsignedTransactionData({
                        contractAddress: action.contractAddress,
                        nonce: action.nonce,
                        gasLimit: action.gasLimit,
                        value: action.value,
                        chainId: action.chainId,
                        maxFeePerGas: action.maxFeePerGas,
                        maxPriorityFeePerGas: action.maxPriorityFeePerGas,
                        from: action.from,
                        functionName: action.functionName,
                        args: action.args,
                        abi: action.abi,
                    }, action.providerURL);
                    Object.assign(this.jsParameters, {
                        [`generatedUnsignedDataContract${action.priority}`]: generatedUnsignedData,
                    });
                    unsignedTransactionDataObject[`generatedUnsignedDataContract${action.priority}`] = generatedUnsignedData;
                }
                switch (action.type) {
                    case "custom":
                        if (!this.actionFunctions.has(`custom${action.priority}`)) {
                            let customCode = `const custom${action.priority} = ${action.code}\n`;
                            customCode = customCode.replace(/Lit\.Actions\.setResponse\s*\(\s*{\s*response\s*:\s*(.*)\s*}\s*\)/g, (_, responseValue) => {
                                return `concatenatedResponse.custom${action.priority} = ${responseValue}`;
                            });
                            this.actionFunctions.add(`custom${action.priority}`);
                            this.code += customCode;
                        }
                        break;
                    case "fetch":
                        if (!this.actionFunctions.has(`fetch${action.priority}`)) {
                            this.actionFunctions.add(`fetch${action.priority}`);
                            this.code += `const fetch${action.priority} = async () => {
                try {
                    const headers = ${action.apiKey || "undefined"}
                      ? { Authorization: 'Bearer ${action.apiKey}' }
                      : undefined;
                    const response = await fetch(
                      '${action.baseUrl}${action.endpoint}',
                      { headers }
                    );
      
                    const responseJSON = await response.json();
                    let value = responseJSON;
                    const pathParts = '${action.responsePath}'.split('.');
                    
                    for (const part of pathParts) {
                      value = value[part];
                      if (value === undefined) {
                        console.log('Invalid response path at priority ${action.priority}: ${action.responsePath}');
                        break;
                      }
                    }

                    if (checkSignCondition(value, signConditionFetch${action.priority})) {
                        const toSignHash = await hashHex(toSignFetch${action.priority});
                        await Lit.Actions.signEcdsa({
                            toSign: toSignHash,
                            publicKey,
                            sigName: "fetch${action.priority}",
                          });
                          concatenatedResponse.fetch${action.priority} = {value,signed:true};
                    }  else {
                        concatenatedResponse.fetch${action.priority} = {value,signed:false};
                    }
                  } catch (err) {
                    console.log('Error thrown on fetch at priority ${action.priority}: ', err);
                  }
                }\n`;
                        }
                        break;
                    case "contract":
                        if (!this.actionFunctions.has(`contract${action.priority}`)) {
                            this.actionFunctions.add(`contract${action.priority}`);
                            this.code += `const contract${action.priority} = async () => {
               try {
                  await Lit.Actions.signEcdsa({
                      toSign: hashTransaction(generatedUnsignedDataContract${action.priority}),
                      publicKey,
                      sigName: "contract${action.priority}",
                  });
                  concatenatedResponse.contract${action.priority} = generatedUnsignedDataContract${action.priority};
               } catch (err) {
                  console.log('Error thrown on contract at priority ${action.priority}: ', err)
               }
            }\n`;
                        }
                        break;
                }
            }
            let functionCallsCode = [];
            let actionFunctionsArray = Array.from(this.actionFunctions);
            actionFunctionsArray.forEach((funcName, index) => {
                if (!functionCallsCode[index])
                    functionCallsCode[index] = "";
                functionCallsCode[index] += `await ${funcName}();\n`;
            });
            this.code = this.code.replace(/const go = async \(\) => {[\s\S]*go\(\);/m, "");
            functionCallsCode.forEach((code, index) => {
                this.code += `\nconst go${index} = async () => {
        \n\n
        let runCode = false;
        if (useSecureKey) {
          if (CryptoJS) {
            if (hashHex(secureKey) === CONDITIONAL_HASH) {
              runCode = true;
            }
          }
        } else {
          runCode = true;
        }

        if (!runCode) {
          console.log('Invalid secure key, code not running.');
          return;
        } else {
          console.log('Valid secure key, code running.');
        }
        \n\n
        ${code}
        Lit.Actions.setResponse({ response: JSON.stringify(concatenatedResponse) });
      }
      
      if (currentAction === ${index}) {
        go${index}();
      }
      
      \n`;
            });
            this.code = (0, litProtocol_1.bundleCodeManual)(this.code);
            return {
                unsignedTransactionDataObject,
                litActionCode: this.code,
                secureKey: this.secureKey,
            };
        };
        this.generateUnsignedTransactionData = async (data, providerURL) => {
            const validChain = Object.keys(lit_listener_sdk_1.LitChainIds).includes(data?.chainId?.toString());
            if (!validChain) {
                throw new Error(`Invalid chain name. Valid chains: ${Object.keys(lit_listener_sdk_1.LitChainIds)}`);
            }
            const contractInterface = new ethers_1.ethers.utils.Interface(data.abi);
            const provider = new ethers_1.ethers.providers.JsonRpcProvider(providerURL, lit_listener_sdk_1.LitChainIds[data.chainId]);
            let maxFeePerGas;
            let maxPriorityFeePerGas;
            if (!data.maxFeePerGas || !data.maxPriorityFeePerGas) {
                const gasPrice = await provider.getGasPrice();
                maxFeePerGas = gasPrice.mul(2);
                maxPriorityFeePerGas = gasPrice.div(2);
            }
            return {
                to: data.contractAddress,
                nonce: data.nonce || 0,
                chainId: lit_listener_sdk_1.LitChainIds[data?.chainId],
                gasLimit: data.gasLimit
                    ? typeof data.gasLimit === "string" || typeof data.gasLimit === "number"
                        ? ethers_1.ethers.BigNumber.from(data.gasLimit)
                        : data.gasLimit
                    : ethers_1.ethers.BigNumber.from("5000000"),
                maxFeePerGas: data.maxFeePerGas
                    ? typeof data.maxFeePerGas === "string" ||
                        typeof data.maxFeePerGas === "number"
                        ? ethers_1.ethers.BigNumber.from(data.maxFeePerGas)
                        : data.maxFeePerGas
                    : maxFeePerGas,
                maxPriorityFeePerGas: data.maxPriorityFeePerGas
                    ? typeof data.maxPriorityFeePerGas === "string" ||
                        typeof data.maxPriorityFeePerGas === "number"
                        ? ethers_1.ethers.BigNumber.from(data.maxPriorityFeePerGas)
                        : data.maxPriorityFeePerGas
                    : maxPriorityFeePerGas,
                from: data.from ? data.from : "{{publicKey}}",
                data: contractInterface.encodeFunctionData(data.functionName, data.args ? data.args : []),
                value: data.value
                    ? typeof data.value === "string" || typeof data.value === "number"
                        ? ethers_1.ethers.BigNumber.from(data.value)
                        : data.value
                    : ethers_1.ethers.BigNumber.from(0),
                type: 2,
            };
        };
        this.getIPFSHash = async (code) => {
            try {
                return await ipfs_only_hash_1.default.of(code);
            }
            catch (err) {
                throw new Error(`Error hashing Lit Action code: ${err.message}`);
            }
        };
        this.mintGrantBurnPKP = async (cidIPFS) => {
            try {
                const mintGrantBurnLogs = await this.mintNextPKP(cidIPFS);
                const pkpTokenId = BigInt(mintGrantBurnLogs[0].topics[1]).toString();
                const publicKey = await this.getPubKeyByPKPTokenId(pkpTokenId);
                this.publicKey = publicKey;
                this.pkpAddress = ethers_1.ethers.utils.computeAddress(publicKey);
                const permissionContract = new ethers_1.Contract(constants_1.PKP_PERMISSIONS_CONTRACT_ADDRESS, PKPPermissions_json_1.default, this.signer);
                let address = await this.signer.getAddress();
                address = ethers_1.ethers.utils.getAddress(address);
                let tx = await permissionContract.addPermittedAddress(pkpTokenId, address, [1]);
                tx = await tx.wait();
                for (const action of this.actions) {
                    let code = action.code;
                    if (!code) {
                        continue;
                    }
                    let cid = await this.getIPFSHash(code);
                    tx = await permissionContract.addPermittedAction(pkpTokenId, (0, litProtocol_1.getBytesFromMultihash)(cid), [1]);
                    await tx.wait();
                }
                return {
                    tokenId: pkpTokenId,
                    publicKey: publicKey,
                    address: ethers_1.ethers.utils.computeAddress(publicKey),
                };
            }
            catch (err) {
                throw new Error(`Error in mintGrantBurn: ${err.message}`);
            }
        };
        this.start = async ({ publicKey, ipfsCID, sessionSig, secureKey, broadcast, }) => {
            if (this.isRunning) {
                throw new Error("Circuit is already running");
            }
            this.isRunning = true;
            try {
                if (this.actions.length > 0) {
                    if (!publicKey || !publicKey.toLowerCase().startsWith("0x04")) {
                        this.log(lit_listener_sdk_1.LogCategory.ERROR, `Invalid PKP Public Key.`, publicKey, new Date().toISOString());
                        throw new Error(`Invalid PKP Public Key.`);
                    }
                    this.publicKey = publicKey;
                    this.pkpAddress = ethers_1.ethers.utils.computeAddress(publicKey);
                    if (ipfsCID) {
                        this.ipfsCID = ipfsCID;
                    }
                    if (sessionSig) {
                        this.sessionSig = sessionSig;
                    }
                    if (secureKey) {
                        this.secureKey = secureKey;
                        this.useSecureKey = true;
                    }
                    await this.connectLit();
                    while (this.continueRun) {
                        const monitors = [];
                        const conditionPromises = [];
                        if (this.conditions.length > 0) {
                            for (const condition of this.conditions) {
                                condition.sdkOnMatched = async () => {
                                    this.satisfiedConditions.add(condition.id);
                                };
                                condition.sdkOnUnMatched = async () => {
                                    this.satisfiedConditions.delete(condition.id);
                                };
                                const conditionPromise = this.monitor.createCondition(condition, this.errorHandlingModeStrict);
                                if (this.conditionalLogic?.interval) {
                                    const timeoutPromise = new Promise((resolve) => setTimeout(resolve, this.conditionalLogic.interval));
                                    conditionPromises.push(Promise.race([conditionPromise, timeoutPromise]).then(() => {
                                        return Promise.resolve();
                                    }));
                                    const monitor = setTimeout(async () => {
                                        await conditionPromise;
                                    }, this.conditionalLogic.interval);
                                    monitors.push(monitor);
                                }
                                else {
                                    conditionPromises.push(conditionPromise);
                                }
                            }
                            if (!this.continueRun)
                                break;
                            await Promise.all(conditionPromises);
                        }
                        else {
                            this.log(lit_listener_sdk_1.LogCategory.CONDITION, "No conditions set, skipping condition checks.", "", new Date().toISOString());
                        }
                        const conditionResBefore = this.checkConditionalLogicAndRun();
                        const executionResBefore = this.checkExecutionLimitations();
                        this.conditionExecutedCount++;
                        this.log(lit_listener_sdk_1.LogCategory.EXECUTION, "Condition Monitor Count Increased", String(this.conditionExecutedCount), new Date().toISOString());
                        if (conditionResBefore === lit_listener_sdk_1.RunStatus.ACTION_RUN &&
                            executionResBefore === lit_listener_sdk_1.RunStatus.ACTION_RUN) {
                            await this.runLitAction(broadcast);
                            const executionResAfter = this.checkExecutionLimitations();
                            if (executionResAfter === lit_listener_sdk_1.RunStatus.EXIT_RUN) {
                                this.log(lit_listener_sdk_1.LogCategory.CONDITION, `Execution Condition Not Met to Continue Circuit.`, `Run Status ${lit_listener_sdk_1.RunStatus.EXIT_RUN}`, new Date().toISOString());
                                this.emitter.emit("stop");
                                break;
                            }
                        }
                        else if (conditionResBefore === lit_listener_sdk_1.RunStatus.EXIT_RUN ||
                            executionResBefore === lit_listener_sdk_1.RunStatus.EXIT_RUN) {
                            this.log(lit_listener_sdk_1.LogCategory.CONDITION, `Execution Condition Not Met to Continue Circuit.`, `Run Status ${lit_listener_sdk_1.RunStatus.EXIT_RUN}`, new Date().toISOString());
                            this.emitter.emit("stop");
                            break;
                        }
                        if (!this.continueRun)
                            break;
                        if (this.conditionalLogic?.interval) {
                            await new Promise((resolve) => setTimeout(resolve, this.conditionalLogic?.interval));
                        }
                        monitors.forEach((monitor) => clearTimeout(monitor));
                        const conditionResEnd = this.checkConditionalLogicAndRun();
                        const executionResEnd = this.checkExecutionLimitations();
                        if (conditionResEnd === lit_listener_sdk_1.RunStatus.EXIT_RUN ||
                            executionResEnd === lit_listener_sdk_1.RunStatus.EXIT_RUN) {
                            this.log(lit_listener_sdk_1.LogCategory.CONDITION, `Execution Condition Not Met to Continue Circuit.`, `Run Status ${lit_listener_sdk_1.RunStatus.EXIT_RUN}`, new Date().toISOString());
                            this.emitter.emit("stop");
                            break;
                        }
                    }
                }
                else if (this.actions.length < 1) {
                    throw new Error(`Actions have not been set. Run setActions() first.`);
                }
            }
            catch (err) {
                throw new Error(`Error running circuit: ${err.message}`);
            }
            finally {
                await Promise.all(this.pendingBroadcasts.map((p) => p));
                this.isRunning = false;
            }
        };
        this.getLogs = (category) => {
            const logsInOrder = [
                ...this.logs.slice(this.logIndex),
                ...this.logs.slice(0, this.logIndex),
            ].filter((log) => log !== undefined);
            if (!category) {
                return logsInOrder;
            }
            return logsInOrder.filter((log) => log.category === category);
        };
        this.generateSessionSignature = async (pkpPublicKey, resources = [], chainId = 1, uri = "https://localhost/login", version = "1") => {
            try {
                return (0, litProtocol_1.generateSessionSig)(this.litClient, this.signer, pkpPublicKey, resources, chainId, uri, version);
            }
            catch (err) {
                throw new Error(`Error generating Auth Signature: ${err.message}`);
            }
        };
        this.interrupt = () => {
            this.emitter.emit("stop");
            this.log(lit_listener_sdk_1.LogCategory.ERROR, "Circuit forcefully interrupted at ", `${Date.now()}`, new Date().toISOString());
        };
        this.mintNextPKP = async (ipfsCID) => {
            if (!this.signer.provider) {
                throw new Error("No provider attached to ethers signer");
            }
            try {
                let address = await this.signer.getAddress();
                address = ethers_1.ethers.utils.getAddress(address);
                const tx = await this.pkpContract.mintNext(2, {
                    value: "1",
                });
                const receipt = await tx.wait();
                const logs = receipt.logs;
                return logs;
            }
            catch (err) {
                throw new Error(`Error in mintGrantBurnPKP: ${err.message}`);
            }
        };
        this.runLitAction = async (broadcast) => {
            try {
                const actionPromises = [];
                let actions = Array.from(this.actionFunctions);
                for (const [i, _] of actions.entries()) {
                    const action = this.actions[i];
                    let promise;
                    if (action.type === "contract") {
                        const providerURL = action.providerURL;
                        const chainId = lit_listener_sdk_1.LitChainIds[action.chainId];
                        const provider = new ethers_1.ethers.providers.JsonRpcProvider(providerURL, chainId);
                        const blockchainNonce = await provider.getTransactionCount(this.pkpAddress);
                        let currentNonce = Math.max(this.lastSuccessfulNonce.get(chainId) || 0, blockchainNonce);
                        this.jsParameters[`generatedUnsignedDataContract${action.priority}`].nonce = currentNonce;
                        currentNonce++;
                        this.lastSuccessfulNonce.set(chainId, currentNonce);
                        const pkpPublicKey = ethers_1.ethers.utils.computeAddress(this.publicKey);
                        const session = await this.generateSessionSignature(this.publicKey);
                        promise = this.litClient.executeJs({
                            ipfsId: this.ipfsCID ? this.ipfsCID : undefined,
                            code: this.ipfsCID ? undefined : this.code,
                            sessionSigs: session,
                            jsParams: {
                                pkpAddress: pkpPublicKey,
                                publicKey: this.publicKey,
                                ...this.jsParameters,
                                currentAction: i,
                                secureKey: this.secureKey,
                                useSecureKey: this.useSecureKey,
                            },
                        });
                        promise.catch(() => {
                            currentNonce--;
                            this.lastSuccessfulNonce.set(chainId, currentNonce);
                        });
                    }
                    else {
                        const pkpPublicKey = ethers_1.ethers.utils.computeAddress(this.publicKey);
                        const session = await this.generateSessionSignature(this.publicKey);
                        promise = this.litClient.executeJs({
                            ipfsId: this.ipfsCID ? this.ipfsCID : undefined,
                            code: this.ipfsCID ? undefined : this.code,
                            sessionSigs: session,
                            jsParams: {
                                pkpAddress: pkpPublicKey,
                                publicKey: this.publicKey,
                                ...this.jsParameters,
                                currentAction: i,
                                secureKey: this.secureKey,
                                useSecureKey: this.useSecureKey,
                            },
                        });
                    }
                    actionPromises.push(promise);
                }
                const response = (await Promise.all(actionPromises)).flat();
                let combinedResponse = { signatures: {}, response: {}, logs: "" };
                let counter = 0;
                response.forEach((res) => {
                    combinedResponse.signatures = {
                        ...combinedResponse.signatures,
                        ...res.signatures,
                    };
                    if (typeof res.response === "object") {
                        combinedResponse.response = {
                            ...combinedResponse.response,
                            ...res.response,
                        };
                    }
                    else {
                        combinedResponse.response = {
                            ...combinedResponse.response,
                        };
                        combinedResponse.response[counter] = res.response;
                    }
                    combinedResponse.logs += "\n" + res.logs;
                    counter += 1;
                });
                if (broadcast) {
                    if ("signatures" in combinedResponse) {
                        const priorities = Object.keys(combinedResponse.signatures)
                            .map((key) => {
                            const match = key.match(/^contract(\d+)$/);
                            return match ? parseInt(match[1], 10) : null;
                        })
                            .filter((priority) => priority !== null)
                            .sort((a, b) => a - b);
                        await this.broadcastContractActions(priorities, combinedResponse);
                    }
                }
                this.log(lit_listener_sdk_1.LogCategory.RESPONSE, "Circuit executed successfully. Lit Action Response.", typeof combinedResponse === "object"
                    ? JSON.stringify(combinedResponse)
                    : combinedResponse, new Date().toISOString());
                this.litActionCompletionCount++;
                this.log(lit_listener_sdk_1.LogCategory.EXECUTION, "Lit Action Completion Increased", String(this.litActionCompletionCount), new Date().toISOString());
            }
            catch (err) {
                this.log(lit_listener_sdk_1.LogCategory.ERROR, `Lit Action failed.`, err.message, new Date().toISOString());
                if (this.errorHandlingModeStrict) {
                    throw new Error(`Error running Lit Action: ${err.message}`);
                }
            }
        };
        this.connectLit = async () => {
            try {
                await this.litClient.connect();
            }
            catch (err) {
                throw new Error(`Error connecting with LitJsSDK: ${err.message}`);
            }
        };
        this.checkExecutionLimitations = () => {
            if (this.conditionMonitorExecutions === undefined &&
                this.startDate === undefined &&
                this.endDate === undefined &&
                this.maxLitActionCompletions === undefined) {
                return lit_listener_sdk_1.RunStatus.ACTION_RUN;
            }
            const withinExecutionLimit = this.conditionMonitorExecutions
                ? this.conditionExecutedCount < this.conditionMonitorExecutions
                : true;
            const withinTimeRange = this.startDate && this.endDate
                ? new Date() >= this.startDate && new Date() <= this.endDate
                : this.startDate && !this.endDate
                    ? new Date() >= this.startDate
                    : this.endDate && !this.startDate
                        ? new Date() <= this.endDate
                        : true;
            const withinSuccessfulCompletions = this.maxLitActionCompletions
                ? this.litActionCompletionCount < this.maxLitActionCompletions
                : true;
            const executionConstraintsMet = withinExecutionLimit && withinTimeRange && withinSuccessfulCompletions;
            if (!executionConstraintsMet) {
                return lit_listener_sdk_1.RunStatus.EXIT_RUN;
            }
            else {
                return lit_listener_sdk_1.RunStatus.ACTION_RUN;
            }
        };
        this.broadcastContractActions = async (priorities, combinedResponse) => {
            for (const priority of priorities) {
                const action = this.actions.find((action) => action.priority === priority);
                if (action) {
                    const signature = combinedResponse.signatures[`contract${priority}`];
                    const sig = signature;
                    const encodedSignature = (0, bytes_1.joinSignature)({
                        r: "0x" + sig.r,
                        s: "0x" + sig.s,
                        recoveryParam: sig.recid,
                    });
                    const provider = new ethers_1.ethers.providers.JsonRpcProvider(action.providerURL, lit_listener_sdk_1.LitChainIds[action.chainId]);
                    const serialized = (0, transactions_1.serialize)(this.jsParameters[`generatedUnsignedDataContract${action.priority}`], encodedSignature);
                    const transactionHash = await provider.sendTransaction(serialized);
                    try {
                        await transactionHash.wait();
                    }
                    catch (err) {
                        this.log(lit_listener_sdk_1.LogCategory.ERROR, `Broadcast Failed.`, err.message, new Date().toISOString());
                        if (this.errorHandlingModeStrict) {
                            throw new Error(`Error in broadcasting Contract Action: ${err.message}`);
                        }
                    }
                    this.log(lit_listener_sdk_1.LogCategory.BROADCAST, `Contract Action broadcast to chain ${action.chainId} successfully. Lit Action Response.`, JSON.stringify(transactionHash), new Date().toISOString());
                }
            }
        };
        this.checkConditionalLogicAndRun = () => {
            if (this.conditionalLogic) {
                switch (this.conditionalLogic.type) {
                    case "THRESHOLD":
                        if (this.conditionalLogic.value &&
                            this.satisfiedConditions.size >= this.conditionalLogic.value) {
                            return lit_listener_sdk_1.RunStatus.ACTION_RUN;
                        }
                        else {
                            return lit_listener_sdk_1.RunStatus.CONTINUE_RUN;
                        }
                    case "TARGET":
                        if (this.conditionalLogic.targetCondition &&
                            this.satisfiedConditions.has(this.conditionalLogic.targetCondition)) {
                            return lit_listener_sdk_1.RunStatus.ACTION_RUN;
                        }
                        else {
                            return lit_listener_sdk_1.RunStatus.CONTINUE_RUN;
                        }
                    case "EVERY":
                        if (this.satisfiedConditions.size === this.conditions.length) {
                            return lit_listener_sdk_1.RunStatus.ACTION_RUN;
                        }
                        else {
                            return lit_listener_sdk_1.RunStatus.CONTINUE_RUN;
                        }
                }
            }
            else {
                return lit_listener_sdk_1.RunStatus.CONTINUE_RUN;
            }
        };
        this.log = (category, message, responseObject, isoDate) => {
            if (typeof responseObject === "object") {
                responseObject = JSON.stringify(responseObject);
            }
            this.logs[this.logIndex] = { category, message, responseObject, isoDate };
            this.logIndex = (this.logIndex + 1) % this.logSize;
            this.emit("log", JSON.stringify({
                message,
                responseObject,
                isoDate,
            }));
        };
        this.errorHandlingModeStrict = errorHandlingModeStrict;
        this.signer = signer ? signer : ethers_1.ethers.Wallet.createRandom();
        this.litClient = new LitJsSdk.LitNodeClient({
            litNetwork: "cayenne",
            debug: false,
        });
        this.monitor = new conditions_1.ConditionMonitor();
        this.conditionalLogic = { type: "EVERY", interval: 1800000 };
        this.monitor.on("conditionMatched", (emittedValue) => {
            this.log(lit_listener_sdk_1.LogCategory.CONDITION, `Condition Matched with Emitted Value: `, JSON.stringify(emittedValue), new Date().toISOString());
        });
        this.monitor.on("conditionNotMatched", (emittedValue) => {
            this.log(lit_listener_sdk_1.LogCategory.CONDITION, `Condition Not Matched with Emitted Value: `, JSON.stringify(emittedValue), new Date().toISOString());
        });
        this.monitor.on("conditionError", (error, condition) => {
            this.log(lit_listener_sdk_1.LogCategory.ERROR, `Error in condition monitoring with condition ${condition.id}`, typeof error === "object" ? JSON.stringify(error) : error, new Date().toISOString());
        });
        this.actionFunctions = new Set();
        this.pkpContract = new ethers_1.ethers.Contract(pkpContractAddress, PKPNFT_json_1.default, this.signer);
        this.pkpHelperContract = new ethers_1.ethers.Contract(pkpHelperContractAddress, PKPHelper_json_1.default, this.signer);
        this.emitter.on("stop", () => {
            this.continueRun = false;
        });
    }
    async getPubKeyByPKPTokenId(tokenId) {
        try {
            return await this.pkpContract.getPubkey(tokenId);
        }
        catch (err) {
            throw new Error(`Error getting pkp public key: ${err.message}`);
        }
    }
}
exports.Circuit = Circuit;
