"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bundleCodeManual = exports.hashHex = exports.generateSecureRandomKey = exports.getBytesFromMultihash = exports.generateSessionSig = void 0;
const ethers_1 = require("ethers");
const bs58_1 = __importDefault(require("bs58"));
const constants_1 = require("./../../src/constants");
const auth_helpers_1 = require("@lit-protocol/auth-helpers");
let crypto, CryptoJS;
const loadNodebuild = async () => {
    if (typeof window === "undefined") {
        const stream = await Promise.resolve().then(() => __importStar(require("stream")));
        crypto = await Promise.resolve().then(() => __importStar(require("crypto")));
        CryptoJS = await Promise.resolve().then(() => __importStar(require("crypto-js")));
    }
};
loadNodebuild();
const generateSessionSig = async (client, signer, pkpPublicKey, resources = [], chainId = 1, uri = "https://localhost/login", version = "1") => {
    try {
        resources =
            resources.length > 0
                ? resources
                : [
                    {
                        resource: new auth_helpers_1.LitPKPResource("*"),
                        ability: auth_helpers_1.LitAbility.PKPSigning,
                    },
                    {
                        resource: new auth_helpers_1.LitActionResource("*"),
                        ability: auth_helpers_1.LitAbility.LitActionExecution,
                    },
                ];
        const sessionSigs = await client.getSessionSigs({
            chain: "ethereum",
            resourceAbilityRequests: resources,
            authNeededCallback: async (params) => {
                console.log("resourceAbilityRequests:", params.resources);
                if (!params.expiration) {
                    throw new Error("expiration is required");
                }
                if (!params.resources) {
                    throw new Error("resourceAbilityRequests is required");
                }
                if (!params.uri) {
                    throw new Error("uri is required");
                }
                const blockHash = await client.getLatestBlockhash();
                const authSig = await generateAuthSig(client, signer, blockHash, params.resourceAbilityRequests, 1, params.uri);
                return authSig;
            },
        });
        return sessionSigs;
    }
    catch (err) {
        throw new Error(`Error generating signed message ${err}`);
    }
};
exports.generateSessionSig = generateSessionSig;
const generateAuthSig = async (client, signer, blockHash, resources, chainId = 1, uri = "https://localhost/login", version = "1") => {
    let address = await signer.getAddress();
    address = ethers_1.ethers.utils.getAddress(address);
    const message = await (0, auth_helpers_1.createSiweMessageWithRecaps)({
        walletAddress: address,
        nonce: blockHash,
        litNodeClient: client,
        expiration: new Date(Date.now() + 24 * 60 * 60 * 1000).toISOString(),
        resources,
        uri,
    });
    const sig = await signer.signMessage(message);
    return {
        sig,
        derivedVia: "web3.eth.personal.sign",
        signedMessage: message,
        address: address,
    };
};
const getBytesFromMultihash = (multihash) => {
    const decoded = bs58_1.default.decode(multihash);
    return `0x${Buffer.from(decoded).toString("hex")}`;
};
exports.getBytesFromMultihash = getBytesFromMultihash;
const generateSecureRandomKey = () => {
    if (!crypto) {
        throw new Error("This function can only be run in a Node.js environment.");
    }
    return crypto.randomBytes(32).toString("hex");
};
exports.generateSecureRandomKey = generateSecureRandomKey;
const hashHex = (input) => {
    if (!CryptoJS) {
        throw new Error("This function can only be run in a Node.js environment.");
    }
    const hash = CryptoJS.SHA256(input);
    return "0x" + hash.toString(CryptoJS.enc.Hex);
};
exports.hashHex = hashHex;
const bundleCodeManual = (dynamicCode) => {
    return constants_1.DENO_BUNDLED + "\n\n" + dynamicCode;
};
exports.bundleCodeManual = bundleCodeManual;
