"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./../src/constants/index");
const PKPNFT_json_1 = __importDefault(require("./../src/abis/PKPNFT.json"));
const PKPPermissions_json_1 = __importDefault(require("./../src/abis/PKPPermissions.json"));
const circuit_1 = require("../src/circuit");
const litProtocol_1 = require("./../src/utils/litProtocol");
const lit_listener_sdk_1 = require("./../src/@types/lit-listener-sdk");
const hardhat_1 = require("hardhat");
const chai_1 = require("chai");
const chronicleProvider = new hardhat_1.ethers.providers.JsonRpcProvider(index_1.CHRONICLE_PROVIDER, 175177);
describe("MintGrantBurnPKP", () => {
    let LitActionCode, ipfsCID, randomNonce, pkpTokenId, pkpNftPublicKey, newCircuit;
    const pkpContract = new hardhat_1.ethers.Contract(index_1.PKP_CONTRACT_ADDRESS, PKPNFT_json_1.default, chronicleProvider);
    const init = async () => {
        newCircuit = new circuit_1.Circuit(new hardhat_1.ethers.Wallet("0x2a871d0798f97d79848a013d4936a73bf4cc922c825d33c1cf7073dff6d409c6", chronicleProvider));
        newCircuit.setConditionalLogic({
            type: "EVERY",
            interval: 10000,
        });
        newCircuit.setConditions([
            new lit_listener_sdk_1.WebhookCondition("https://api.weather.gov", "/zones/forecast/MIZ018/forecast", "geometry.type", "Polygon", "===", undefined, async () => {
                console.log("matched");
            }, async () => {
                console.log("unmatched");
            }, (err) => console.error(err.message)),
        ]);
        const res = await newCircuit.setActions([
            {
                type: "custom",
                priority: 0,
                code: `async () => {
          Lit.Actions.setResponse({response: "Transaction Signed Successfully."});
        }`,
            },
        ]);
        LitActionCode = res.litActionCode;
        newCircuit.executionConstraints({
            conditionMonitorExecutions: 1,
        });
        ipfsCID = await newCircuit.getIPFSHash(LitActionCode);
    };
    const createPkp = async (pkpContract) => {
        const pkpTokenData = await newCircuit.mintGrantBurnPKP(ipfsCID);
        pkpTokenId = pkpTokenData.tokenId;
        pkpNftPublicKey = await pkpContract.getPubkey(pkpTokenId);
    };
    it("Generates the IPFSCID of the Lit Action Code", async () => {
        if (!ipfsCID) {
            await init();
        }
        const sameIpfsCID = await newCircuit.getIPFSHash(LitActionCode);
        (0, chai_1.expect)(typeof ipfsCID).to.equal("string");
        (0, chai_1.expect)(ipfsCID).to.equal(sameIpfsCID);
        (0, chai_1.expect)(ipfsCID).to.not.be.false;
    });
    it("The PKP is Correctly Granted Permission to Run the ipfsCID", async () => {
        if (!ipfsCID) {
            await init();
        }
        if (!pkpTokenId) {
            await createPkp(pkpContract);
        }
        const pkpPermissionsContract = new hardhat_1.ethers.Contract(index_1.PKP_PERMISSIONS_CONTRACT_ADDRESS, PKPPermissions_json_1.default, chronicleProvider);
        const [permittedAction] = await pkpPermissionsContract.getPermittedActions(hardhat_1.ethers.BigNumber.from(pkpTokenId));
        (0, chai_1.expect)((0, litProtocol_1.getBytesFromMultihash)(ipfsCID)).to.equal(permittedAction);
    });
    it("The tokenID Has No Owner", async () => {
        if (!pkpTokenId) {
            await createPkp(pkpContract);
        }
    });
    it("PKP should successfully execute the Lit Action that was Granted upon Mint and Burn", async () => {
        await newCircuit.start({
            publicKey: pkpNftPublicKey,
        });
        const responseLog = newCircuit.getLogs(lit_listener_sdk_1.LogCategory.RESPONSE);
        (0, chai_1.expect)(responseLog.length).to.equal(1);
        (0, chai_1.expect)(responseLog[0].category).to.equal(1);
        (0, chai_1.expect)(responseLog[0].message.trim()).to.equal(`Circuit executed successfully. Lit Action Response.`.trim());
        (0, chai_1.expect)(responseLog[0].responseObject).to.include('{"signatures":{},"response":{"0":"{\\"custom0\\":\\"Transaction Signed Successfully.\\"}"},"logs":"\\nValid secure key, code running.\\n"}');
    });
});
